==> dotnet9_9.0.111-9.0.10.orig.tar.xz: src/wpf/src/Microsoft.DotNet.Wpf/src/System.Xaml/System/Windows/Markup/XamlSetTypeConverterEventArgs.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

#nullable disable

using System.ComponentModel;
using System.Globalization;
using System.Xaml;

namespace System.Windows.Markup
{
    public class XamlSetTypeConverterEventArgs : XamlSetValueEventArgs
    {
        public XamlSetTypeConverterEventArgs(XamlMember member, TypeConverter typeConverter, object value,
            ITypeDescriptorContext serviceProvider, CultureInfo cultureInfo) :
            base(member, value)
        {
            TypeConverter = typeConverter;
            ServiceProvider = serviceProvider;
            CultureInfo = cultureInfo;
        }

        internal XamlSetTypeConverterEventArgs(XamlMember member, TypeConverter typeConverter, object value,
            ITypeDescriptorContext serviceProvider, CultureInfo cultureInfo, object targetObject) :
            this(member, typeConverter, value, serviceProvider, cultureInfo)
        {
            TargetObject = targetObject;
        }

        public TypeConverter TypeConverter { get; private set; }
        public ITypeDescriptorContext ServiceProvider { get; private set; }
        public CultureInfo CultureInfo { get; private set; }

        internal object TargetObject { get; private set; }
        internal XamlType CurrentType { get; set; }

        public override void CallBase()
        {
            if (CurrentType != null)
            {
                XamlType baseType = CurrentType.BaseType;
                if (baseType != null)
                {
                    CurrentType = baseType;
                    if (baseType.SetTypeConverterHandler != null)
                    {
                        baseType.SetTypeConverterHandler(TargetObject, this);
                    }
                }
            }
        }
    }
}

==> dotnet10_10.0.100-10.0.0.orig.tar.xz: src/wpf/src/Microsoft.DotNet.Wpf/src/System.Xaml/System/Windows/Markup/XamlSetTypeConverterEventArgs.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

#nullable disable

using System.ComponentModel;
using System.Globalization;
using System.Xaml;

namespace System.Windows.Markup
{
    public class XamlSetTypeConverterEventArgs : XamlSetValueEventArgs
    {
        public XamlSetTypeConverterEventArgs(XamlMember member, TypeConverter typeConverter, object value,
            ITypeDescriptorContext serviceProvider, CultureInfo cultureInfo) :
            base(member, value)
        {
            TypeConverter = typeConverter;
            ServiceProvider = serviceProvider;
            CultureInfo = cultureInfo;
        }

        internal XamlSetTypeConverterEventArgs(XamlMember member, TypeConverter typeConverter, object value,
            ITypeDescriptorContext serviceProvider, CultureInfo cultureInfo, object targetObject) :
            this(member, typeConverter, value, serviceProvider, cultureInfo)
        {
            TargetObject = targetObject;
        }

        public TypeConverter TypeConverter { get; private set; }
        public ITypeDescriptorContext ServiceProvider { get; private set; }
        public CultureInfo CultureInfo { get; private set; }

        internal object TargetObject { get; private set; }
        internal XamlType CurrentType { get; set; }

        public override void CallBase()
        {
            if (CurrentType is not null)
            {
                XamlType baseType = CurrentType.BaseType;
                if (baseType is not null)
                {
                    CurrentType = baseType;
                    if (baseType.SetTypeConverterHandler is not null)
                    {
                        baseType.SetTypeConverterHandler(TargetObject, this);
                    }
                }
            }
        }
    }
}
